/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.plugins.ide.internal.resolver.model;

import java.io.File;

public class UnresolvedIdeRepoFileDependency extends IdeExtendedRepoFileDependency {

    private final Throwable problem;
    private final String displayName;

    public UnresolvedIdeRepoFileDependency(String declaredConfiguration, File file, Throwable problem, String displayName) {
        super(declaredConfiguration, file);

        this.displayName = displayName;
        this.problem = problem;
    }

    public Throwable getProblem() {
        return problem;
    }

    public String getDisplayName() {
        return displayName;
    }
}
